@@ -23,6 +23,7 @@
 
 #include "gpg-error.h"
 #include "visibility.h"
+#include "protos.h"
 
 /*
  * Internal i18n macros.
@@ -339,6 +340,7 @@ gpgrt_stream_t _gpgrt_fopencookie (void *_GPGRT__RESTRICT cookie,
                                    const char *_GPGRT__RESTRICT mode,
                                    gpgrt_cookie_io_functions_t functions);
 int _gpgrt_fclose (gpgrt_stream_t stream);
+int _gpgrt_fcancel (gpgrt_stream_t stream);
 int _gpgrt_fclose_snatch (gpgrt_stream_t stream,
                           void **r_buffer, size_t *r_buflen);
 int _gpgrt_onclose (gpgrt_stream_t stream, int mode,
@@ -792,6 +794,9 @@ gpg_err_code_t _gpgrt_chdir (const char *name);
 /* Return the current WD as a malloced string.  */
 char *_gpgrt_getcwd (void);
 
+/* Wrapper for Windows to allow utf8 file names.  */
+gpg_err_code_t _gpgrt_access (const char *fname, int mode);
+
 /* Return the home directory of user NAME.  */
 char *_gpgrt_getpwdir (const char *name);
 
@@ -815,6 +820,9 @@ char *_gpgrt_absfnameconcat (const char *first_part,
 char *_gpgrt_w32_reg_query_string (const char *root,
                                    const char *dir,
                                    const char *name);
+char *_gpgrt_w32_reg_get_string (const char *key);
+
+wchar_t *_gpgrt_fname_to_wchar (const char *fname);
 
 
 #endif /*HAVE_W32_SYSTEM*/
